'use strict';

var os = require('os');
var fs = require('fs');
var path = require('path');

var verifyFile = require('./lib/verify-file');

var platform = os.platform() + '-' + os.arch();

var packageName = '@ffmpeg-installer/' + platform;

if (!require('./package.json').optionalDependencies[packageName]) {
  throw 'Unsupported platform/architecture: ' + platform;
}

var binary = os.platform() === 'win32' ? 'ffmpeg.exe' : 'ffmpeg';

var npm3Path = path.resolve(__dirname, '..', platform);
var npm2Path = path.resolve(
  __dirname,
  'node_modules',
  '@ffmpeg-installer',
  platform,
);

var npm3Binary = path.join(npm3Path, binary);
var npm2Binary = path.join(npm2Path, binary);

var npm3Package = path.join(npm3Path, 'package.json');
var npm2Package = path.join(npm2Path, 'package.json');

var ffmpegPath, packageJson;

console.log('hello');

if (verifyFile(npm3Binary)) {
  ffmpegPath = npm3Binary;
  packageJson = require(npm3Package);
} else if (verifyFile(npm2Binary)) {
  ffmpegPath = npm2Binary;
  packageJson = require(npm2Package);
} else {
  console.log(os.platform());
  if (os.platform() === 'darwin') {
    // hack to exit if we are on host machine
    return;
  }

  console.log(process.env.LAMBDA_TASK_ROOT);
  if (process.env.LAMBDA_TASK_ROOT) {
    console.log(Object.keys(process.env));
    // print contents of local node modules on lambda
    // copy-ffmpeg
    // set new path
    require('child_process').exec(
      'cp /var/task/ffmpeg /tmp/.; chmod 755 /tmp/ffmpeg;',
      function(error, stdout, stderr) {
        if (error) {
          //handle error
        } else {
          console.log('stdout: ' + stdout);
          console.log('stderr: ' + stderr);
          //handle success
        }
      },
    );
    process.env['FFMPEG_PATH'] = '/tmp/ffmpeg';
    ffmpegPath = '/tmp/ffmpeg';
    return;
  }

  throw 'Could not find ffmpeg executable, tried "' +
    npm3Binary +
    '" and "' +
    npm2Binary +
    '"';
}

var version = packageJson.ffmpeg || packageJson.version;
var url = packageJson.homepage;

module.exports = {
  path: ffmpegPath,
  version: version,
  url: url,
};
